package org.uoc.petrel;

import java.util.List;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.ActionMode;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemLongClickListener;
import android.widget.ListView;
import android.widget.Toast;

public class PortfolioActivity extends Activity {
	private PetrelDBAdapter datasource;
	protected Object mActionMode;
	public int selectedItem = -1;

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_portfolio);

		datasource = new PetrelDBAdapter(this);
		datasource.open();

		List<Portfolio> portfolios = datasource.getAllPortfolios();

		final ListView lv = (ListView) findViewById(R.id.custom_list);
		lv.setAdapter(new PortfolioListAdapter(this, portfolios));
		
		if (portfolios.isEmpty()) {
			Intent PortfolioEditScreen = new Intent(getApplicationContext(),
					PortfolioEditActivity.class);
			startActivity(PortfolioEditScreen);
		}

		lv.setOnItemLongClickListener(new OnItemLongClickListener() {
			@Override
			public boolean onItemLongClick(AdapterView<?> parent, View view,
					int position, long id) {

				if (mActionMode != null) {
					return false;
				}
				selectedItem = position;

				mActionMode = PortfolioActivity.this
						.startActionMode(mActionModeCallback);
				view.setSelected(true);
				return true;
			}
		});
	}
	
	@Override
    public void onWindowFocusChanged(boolean hasFocus) {
		List<Portfolio> portfolios = datasource.getAllPortfolios();

		final ListView lv = (ListView) findViewById(R.id.custom_list);
		lv.setAdapter(new PortfolioListAdapter(this, portfolios));
		
		if (portfolios.isEmpty()) {
			Intent PortfolioEditScreen = new Intent(getApplicationContext(),
					PortfolioEditActivity.class);
			startActivity(PortfolioEditScreen);
		}
    }

	private ActionMode.Callback mActionModeCallback = new ActionMode.Callback() {


		public boolean onCreateActionMode(ActionMode mode, Menu menu) {
			MenuInflater inflater = mode.getMenuInflater();
			inflater.inflate(R.menu.row_selection, menu);
			return true;
		}

		public boolean onPrepareActionMode(ActionMode mode, Menu menu) {
			return false;
		}

		public boolean onActionItemClicked(ActionMode mode, MenuItem item) {
			switch (item.getItemId()) {
			case R.id.menuitem1_show:
				show();
				mode.finish();
				return true;
			case R.id.menuitem2_delete:
				delete();
				mode.finish();
				return true;
			case R.id.menuitem3_new:
				newPortfolio();
				mode.finish();
				return true;
			default:
				return false;
			}
		}

		public void onDestroyActionMode(ActionMode mode) {
			mActionMode = null;
			selectedItem = -1;
		}
	};

	private void show() {
		Toast.makeText(PortfolioActivity.this, String.valueOf(selectedItem),
				Toast.LENGTH_LONG).show();
	}
	
	private void delete() {
		Portfolio portfolio = new Portfolio();
		portfolio.setId(selectedItem);
		datasource.deletePortfolio(portfolio);
	}
	
	private void newPortfolio() {
		Intent PortfolioEditScreen = new Intent(getApplicationContext(),
				PortfolioEditActivity.class);
		startActivity(PortfolioEditScreen);
	}

}
