from mpt import Portfolio
from price_utils import load_from_db

def optimize_portfolio(tickers):
    p = Portfolio(symbols=tickers, 
                  startdate="2012-1-1", 
                  enddate="2012-12-31",
                  dbfilename="api/data/stocks.db")

    rt = 0.5 # Risk tolerance, equivalent to a 50% annual volatility
    drt = rt/252.0 # Convert to a daily volatility using trading days per year
    lb = 0.0 # lower bound of allowed weighting for an asset
    ub = 1.0 # upper bound of allowed weighting for an asset

    weights, variance, ret = p.optimize_portfolio(rt=drt, 
        lower_bound_weight=lb, upper_bound_weight=ub)
    return weights, variance, ret

def predict_volatility(ticker):
    import numpy as np
    from sklearn import cross_validation
    from sklearn import datasets
    from sklearn import svm
    
    ibex35 = load_from_db(ticker, startdate="2012-1-1", 
        enddate="2012-12-31", 
        dbfilename="data/stocks.db")
        
    X, Xtest, y , ytest = cross_validation.train_test_split (
    ibex35.data,
    ibex35.target,
    testsize=0.25)

    cv = cross_validationStratifiedKFold (y, k=10)

    def train_classifier(x, y, param):
        from sklearn.svm import SVR
        clf = SVR(C=1.0, cache_size=200, coef0=0.0, degree=3,
                epsilon=0.1, gamma=0.0, kernel='rbf', max_iter=-1, 
                probability=False, shrinking=True, tol=0.001, 
                verbose=False)
        clf.fit(x, y)
        return clf

    for param in [0.1, 1., 10.] :
        for train , val in cv:
            clf = train_classifier(
            x = x[train],
            y = y[train],
            param = param)

    best_param = max(
        accs.iteritems(),
        key=lambda x: sum(x[1]),
    )[0]

    return clf.predict()

if __name__=="__main__":
    tickers = ["SAN.MC", "CABK.MC", "BME.MC"]
    optimize_portfolio(tickers)

